pub struct TreeNodeKey { /* private fields */ }Expand description
The unique key of each node.
Implementations
Sourceimpl TreeNodeKey
impl TreeNodeKey
Sourcepub fn new(version: Version, nibble_path: NibblePath) -> Self
pub fn new(version: Version, nibble_path: NibblePath) -> Self
Creates a new NodeKey.
Sourcepub fn new_empty_path(version: Version) -> Self
pub fn new_empty_path(version: Version) -> Self
A shortcut to generate a node key consisting of a version and an empty nibble path.
Sourcepub fn nibble_path(&self) -> &NibblePath
pub fn nibble_path(&self) -> &NibblePath
Gets the nibble path.
Sourcepub fn gen_child_node_key(&self, version: Version, n: Nibble) -> Self
pub fn gen_child_node_key(&self, version: Version, n: Nibble) -> Self
Generates a child node key based on this node key.
Sourcepub fn gen_parent_node_key(&self) -> Self
pub fn gen_parent_node_key(&self) -> Self
Generates parent node key at the same version based on this node key.